#!/bin/sh
#
# Written by Geoff Mottram (geoff at minaret dot biz).
#
# Placed in the public domain by the author.
#
# See LICENSE.txt for NO WARRANTY statement.
#

#
# Customization script that installs modified files
# needed for an Lenovo IX2 device.
#

#
# Minimally, the following environment variables will be
# set by the install.sh script:
#
#    TARGET_DEVICE: "sdX"
#     INSTALL_TYPE: "usb" or "ide"
#      DEVICE_TYPE: "all" or shortened DTS name
#        SWAP_SIZE: 256, 512, 768 or 1024 (MiB)
#        ROOT_SIZE: -1=all, or 2-512 (GiB)
#           FSTYPE: "ext2", "ext3" or "ext4"
#        CUSTOMIZE: "orig" or "ix2"
#
# The full path to the target root directory (without a
# trailing slash will be passed in TARGET_ROOT.
#
# The current directory will be this directory.
#

#
# Copy a file with error checking
#
copy_file() {
	if [ -e "$1" ]; then
		#echo "Dry run: cp -pv \"$1\" \"$2\""
		#return
		if cp -pv "$1" "$2"; then
			return
		else
			exit $?
		fi
	fi
	echo "$0: No such source file \"$1\""
	exit 1
}

# Make sure environment variables are set
for NAME in TARGET_ROOT INSTALL_TYPE DEVICE_TYPE; do
	eval VALUE="\$$NAME"
	if [ -z "$VALUE" ]; then
		echo "$0: Environment variable \"$NAME\" is not set"
		exit 1
	fi
done

cat <<END

$0: Installing custom files
From: boot/tools/custom/ix2
  To: $TARGET_ROOT

END

#
# Straight copy
#
COPY_LIST="etc/ntp.conf etc/initramfs-tools/initramfs.conf etc/rc.local etc/rc.ix2"
for NAME in $COPY_LIST; do
	copy_file "$NAME" "$TARGET_ROOT/$NAME"
done

#
# Copy /etc/fstab
#
copy_file "etc/fstab-$INSTALL_TYPE" "$TARGET_ROOT/etc/fstab"
case "$DEVICE_TYPE" in
	(lenovo-ix2-dl)
		NAME="dl"
		;;
	(lenovo-ix2-ng)
		NAME="ng"
		;;
	(*)
		echo "$0: Unexpected DEVICE_TYPE \"$DEVICE_TYPE\""
		exit 1
esac

#
# Copy /etc/fw_env
#
copy_file "etc/fw_env.config-$NAME" "$TARGET_ROOT/etc/fw_env.config"

exit 0
